let circles = []; // Declare an array to store the Circle objects

function setup() {
  createCanvas(800, 800); 

  for (let i = 0; i < 600; i++) { // Create 50 circles
    let x = random(width); // Generate a random x position
    let y = random(height); // Generate a random y position
    let r = random(10, 50); // Generate a random radius
    let col = color((255,0), (255,0,100), (255,100,100)); 
    circles.push(new Circle(x, y, r, col)); // Create a new Circle object and add it to the array
  }
}

function draw() {
  background(0,6); 
  for (let circle of circles) { // Update and display each circle
    circle.move();
    circle.display();
  }
}



class Circle { 
  constructor(x, y, r, col) { // Constructor function to create a new Circle object
    this.x = x; // Initial x position
    this.y = y; // Initial y position
    this.r = r; // Radius
    this.col = col; 
    this.xVelocity = random(-5, 2); // Random initial x velocity
    this.yVelocity = random(-5, 2); // Random initial y velocity
  }

  move() { 
    this.x += this.xVelocity; // Update x position based on velocity
    this.y += this.yVelocity; // Update y position based on velocity

    if (this.x > width || this.x < 0) { // If the circle goes off the canvas, reverse its x velocity
      this.xVelocity *= -1;
    }
    if (this.y > height || this.y < 0) { // If the circle goes off the canvas, reverse its y velocity
      this.yVelocity *= -1;
    }
  }

  display() {
    let fromColor = color(255, 100, 10); // Start color
    let toColor = color(50, 200, 255); // End color
    let interp = map(this.x, 0, width, 0, 1); // Calculate a value between 0 and 1 based on the x position of the circle
    this.col = lerpColor(fromColor, toColor, interp); // Use lerpColor to smoothly transition from one color to another
    fill(this.col); // Set the fill color
    strokeWeight(0);
    ellipse(this.x, this.y, this.r * 2); // Draw the circle
  }
}


